@@ -85,6 +85,14 @@ def get_synchronization_tasks(object_name):
                              AllTasks.success_all("sync_reps"))),
                   'condition': lambda Get: Get('update.cl_update_use_migration_host') == 'off'
                  },
+                 {'name': 'interrupt_on_no_leveled_binhost',
+                  'method': Object("interrupt_on_no_leveled_binhost()"),
+                  'essential': True,
+                  'depend': (Tasks.success() & ~AllTasks.has_any("not_use_search") &
+                             (~AllTasks.success_one_of("check_current_binhost")) &
+                             AllTasks.failed_all("detect_best_binhost")),
+                  'condition': lambda Get: Get('update.cl_update_use_migration_host') == 'off'
+                 },
                  {'name': 'set_migration_binhost',
                   'method': Object('set_migration_host()'),
                   'depend': (Tasks.success() & ~AllTasks.has_any("not_use_search")|
